@@ -1,22 +1,47 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/lib/config_default.php,v 1.17 2005/12/10 10:34:55 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/lib/config_default.php,v 1.27.2.3 2007/12/26 01:47:20 wurley Exp $
 
 /**
  * Configuration processing and defaults.
+ *
  * @author The phpLDAPadmin development team
  * @package phpLDAPadmin
+ *
  * @todo Add validation of set variables to enforce limits or particular values.
  */
 
 # The minimum version of PHP required to run phpLDAPadmin.
-define('REQUIRED_PHP_VERSION','4.1.0');
+define('REQUIRED_PHP_VERSION','5.0.0');
 
+/**
+ * The config class contains all our configuration settings for a session.
+ * 
+ * An instance of this class should be stored in $_SESSION to maintain state, and to avoid
+ * rebuilding/rereading it at the state of each page output.
+ *
+ * @package phpLDAPadmin
+ *
+ * @author The phpLDAPadmin development team
+ * @author Deon George
+ */
 class Config {
-	var $custom;
-	var $default;
+	public $custom;
+	protected $default;
 
-	function Config() {
+	public $ldapservers = array();
+	protected $friendly_attrs = array();
+	public $queries = array();
+	public $attrs_display_order = array();
+	public $hidden_attrs = array();
+	public $hidden_except_dn = '';
+	public $hidden_attrs_ro = array();
+	public $read_only_attrs = array();
+	public $read_only_except_dn = '';
+	public $unique_attrs = array();
 
+	public $hooks = array();
+
+	public function __construct() {
 		$this->custom = new stdClass;
 		$this->default = new stdClass;
 
@@ -33,22 +58,35 @@ class Config {
 		 * Set to true if you want phpLDAPadmin to redirect anonymous
 		 * users to a search form with no tree viewer on the left after
 		 * logging in.
+		 * @todo: With the new no-frames PLA, this code is broken, and needs to be fixed.
 		 */
 		$this->default->appearance['anonymous_bind_redirect_no_tree'] = array(
 			'desc'=>'Redirect user to search form if anonymous',
 			'default'=>false);
 
+		$this->default->appearance['compress'] = array(
+			'desc'=>'Compress Output',
+			'default'=>false);
+
 		$this->default->appearance['date'] = array(
 			'desc'=>'Date format whenever dates are shown',
 			'default'=>'%A %e %B %Y');
 
+		$this->default->appearance['custom_templates_only'] = array(
+			'desc'=>'Only display the custom templates.',
+			'default'=>false);
+
 		$this->default->appearance['date_attrs'] = array(
 			'desc'=>'Array of attributes that should show a jscalendar',
 			'default'=>array('shadowExpire'=>'%es','shadowLastChange'=>'%es'));
 
-		$this->default->appearance['hide_configuration_management'] = array(
-			'desc'=>'Hide the Sourceforge related links',
-			'default'=>false);
+		$this->default->appearance['date_attrs_showtime'] = array(
+			'desc'=>'Array of attributes that should show a the time when showing the jscalendar',
+			'default'=>array(''));
+
+		$this->default->appearance['hide_debug_info'] = array(
+			'desc'=>'Hide the features that may provide sensitive debugging information to the browser',
+			'default'=>true);
 
 		/** Language
 		 * The language setting. If you set this to 'auto', phpLDAPadmin will
@@ -61,21 +99,13 @@ class Config {
 			'desc'=>'Language',
 			'default'=>'auto');
 
-		/** Mass Delete
-		 * Set to true if you want to draw a checkbox next to each entry in the tree viewer
-		 * to be able to delete multiple entries at once
-		 */
-		$this->default->appearance['mass_delete'] = array(
-			'desc'=>'Enable mass delete in tree viewer',
-			'default'=>false);
-
 		/**
 		 * If you want certain attributes to be editable as multi-line, include them in this list
 		 * A multi-line textarea will be drawn instead of a single-line text field
 		 */
 		$this->default->appearance['multi_line_attributes'] = array(
 			'desc'=>'Attributes to show as multiline attributes',
-			'default'=>array("postalAddress","homePostalAddress","personalSignature"));
+			'default'=>array('postalAddress','homePostalAddress','personalSignature','description','mailReplyText'));
 
 		/**
 		 * A list of syntax OIDs which support multi-line attribute values:
@@ -84,9 +114,9 @@ class Config {
 			'desc'=>'Attributes to show as multiline attributes',
 			'default'=>array(
 				// octet string syntax OID:
-				"1.3.6.1.4.1.1466.115.121.1.40",
+				'1.3.6.1.4.1.1466.115.121.1.40',
 				// postal address syntax OID:
-				"1.3.6.1.4.1.1466.115.121.1.41"));
+				'1.3.6.1.4.1.1466.115.121.1.41'));
 
 		/** Obfuscate Password
 		 * If true, display all password hash values as "******". Note that clear-text
@@ -94,7 +124,7 @@ class Config {
 		 */
 		$this->default->appearance['obfuscate_password_display'] = array(
 			'desc'=>'Obfuscate the display of passwords',
-			'default'=>false);
+			'default'=>true);
 
 		$this->default->appearance['show_clear_password'] = array(
 			'desc'=>'Whether to show clear passwords if we dont obfuscate them',
@@ -108,6 +138,32 @@ class Config {
 			'desc'=>'Show helpful hints',
 			'default'=>true);
 
+		$this->default->appearance['show_top_create'] = array(
+			'desc'=>'Show a additional create link on the top of the list if there are more than 10 entries',
+			'default'=>true);
+
+		/*
+		 * What to do after entry creation :
+		 * 2 : display the creation form again
+		 * 1 : display the new created entry
+		 * 0 : display the choice between 1 and 2
+		 */
+		$this->default->appearance['action_after_creation'] = array(
+			'desc'=>'Display the new created entry',
+			'default'=>1);
+
+		$this->default->appearance['show_schema_link'] = array(
+			'desc'=>'Show the schema link for each attribute',
+			'default'=>true);
+
+		$this->default->appearance['show_attribute_notes'] = array(
+			'desc'=>'Show notes for each attribute',
+			'default'=>true);
+
+		$this->default->appearance['stylesheet'] = array(
+			'desc'=>'Style sheet to use',
+			'default'=>'style.css');
+
 		/** Tree display
 		 * A format string used to display enties in the tree viewer (left-hand side)
 		 * You can use special tokens to draw the entries as you wish. You can even mix in HTML to format the string
@@ -137,9 +193,33 @@ class Config {
 			'desc'=>'Pixel width of the left frame view (tree browser)',
 			'default'=>320);
 
-		$this->default->appearance['tree_plm'] = array(
-			'desc'=>'Whether to enable the PHPLayersMenu for the tree',
-			'default'=>false);
+		/**
+		 * Tree display filter
+		 * LDAP filter used to search entries for the tree viewer (left-hand side)
+		 */
+		$this->default->appearance['tree_filter'] = array(
+			'desc'=>'LDAP search filter for the tree entries',
+			'default'=>'(objectClass=*)');
+
+		$this->default->appearance['tree'] = array(
+			'desc'=>'Class name which inherits from Tree class and implements the draw() method',
+			'default'=>'AJAXTree');
+
+		$this->default->appearance['entry_factory'] = array(
+			'desc'=>'Class name which inherits from EntryFactory class',
+			'default'=>'TemplateEntryFactory');
+
+		$this->default->appearance['attribute_factory'] = array(
+			'desc'=>'Class name which inherits from AttributeFactory class',
+			'default'=>'AttributeFactory');
+
+		$this->default->appearance['entry_reader'] = array(
+			'desc'=>'Class name which inherits from EntryReader class',
+			'default'=>'EntryReader');
+
+		$this->default->appearance['entry_writer'] = array(
+			'desc'=>'Class name which inherits from EntryWriter class',
+			'default'=>'EntryWriter1');
 
 		/** Caching
 		 */
@@ -155,19 +235,56 @@ class Config {
 			'desc'=>'Cache Browser Tree',
 			'default'=>true);
 
+		/**
+		 * Define command availability ; if the value of a command is true,
+		 * the command will be available.
+		 */
+		$this->default->commands['all'] = array(
+			'desc'=>'Define command availability',
+			'default'=> array(
+				'home' => true,
+				'external_links' => array('feature' => true,
+					'bug' => true,
+					'donation' => true,
+					'help' => true,
+					'credits' => true),
+				'purge' => true,
+				'schema' => true,
+				'import' => true,
+				'export' => true,
+				'logout' => true,
+				'search' => array('simple_search' => true,
+					'predefined_search' => true,
+					'advanced_search' => true),
+				'server_refresh' => true,
+				'server_info' => true,
+				'entry_refresh' => true,
+				'entry_move' => true,
+				'entry_internal_attributes_show' => true,
+				'entry_delete' => array('simple_delete' => true,
+					'mass_delete' => false),
+				'entry_rename' => true,
+				'entry_compare' => true,
+				'entry_create' => true,
+				'attribute_add' => true,
+				'attribute_add_value' => true,
+				'attribute_delete' => true,
+				'attribute_delete_value' => true
+			));
+
 		/** Aliases and Referrrals
 		 * Similar to ldapsearch's -a option, the following options allow you to configure
 		 * how phpLDAPadmin will treat aliases and referrals in the LDAP tree.
 		 * For the following four settings, avaialable options include:
 		 *
-		 *    LDAP_DEREF_NEVER     - aliases are never dereferenced (eg, the contents of
-		 *                           the alias itself are shown and not the referenced entry).
-		 *    LDAP_DEREF_SEARCHING - aliases should be dereferenced during the search but
-		 *                           not when locating the base object of the search.
-		 *    LDAP_DEREF_FINDING   - aliases should be dereferenced when locating the base
-		 *                           object but not during the search.
-		 *    LDAP_DEREF_ALWAYS    - aliases should be dereferenced always (eg, the contents
-		 *                           of the referenced entry is shown and not the aliasing entry)
+		 * LDAP_DEREF_NEVER	- aliases are never dereferenced (eg, the contents of
+		 *			the alias itself are shown and not the referenced entry).
+		 * LDAP_DEREF_SEARCHING	- aliases should be dereferenced during the search but
+		 *			not when locating the base object of the search.
+		 * LDAP_DEREF_FINDING	- aliases should be dereferenced when locating the base
+		 *			object but not during the search.
+		 * LDAP_DEREF_ALWAYS	- aliases should be dereferenced always (eg, the contents
+		 *			of the referenced entry is shown and not the aliasing entry)
 		 */
 		@$this->default->deref['export'] = array(
 			'desc'=>'',
@@ -198,6 +315,14 @@ class Config {
 			'desc'=>'Name of file to send debug output to',
 			'default'=>null);
 
+		$this->default->debug['addr'] = array(
+			'desc'=>'IP address of PLA client to provide debugging info.',
+			'default'=>null);
+
+		$this->default->debug['append'] = array(
+			'desc'=>'Whether to append to the debug file, or create it fresh each time',
+			'default'=>true);
+
 		/** Temp Directories
 		 * This directory must be readable and writable by your web server
 		 */
@@ -209,6 +334,56 @@ class Config {
 			'desc'=>'Time in seconds to keep jpegPhoto temporary files in the temp directory',
 			'default'=>120);
 
+		## Modify members feature
+		/**
+		 * Search filter setting for new members. This is used to search possible members that can be added
+		 * to the group. See modify_member_form.php
+		 */
+		$this->default->modify_member['filter'] = array(
+			'desc'=>'Search filter for member searches',
+			'default'=>'(objectclass=Person)');
+
+		/**
+		 * Group attributes. When these attributes are seen in template_engine.php, add "modify group members"
+		 * link to the attribute
+		 * See template_engine.php
+		 */
+		$this->default->modify_member['groupattr'] = array(
+			'desc'=>'Group member attributes',
+			'default'=>array('member','uniqueMember','memberUid'));
+
+		/**
+		 * Attribute that is added to the group member attribute. For groupOfNames or groupOfUniqueNames this is dn,
+		 * for posixGroup it's uid. See modify_member_form.php
+		 */
+		$this->default->modify_member['attr'] = array(
+			'desc'=>'Default attribute that is added to the group member attribute',
+			'default'=>'dn');
+
+		/**
+		 * Attribute that is added to the group member attribute.
+		 * For posixGroup it's uid. See modify_member_form.php
+		 */
+		$this->default->modify_member['posixattr'] = array(
+			'desc'=>'Contents of the group member attribute',
+			'default'=>'uid');
+
+		/**
+		 * Search filter setting for new members to group. This is used to search possible members that can be added
+		 * to the posixGroup. See modify_member_form.php
+		 */
+		$this->default->modify_member['posixfilter'] = array(
+			'desc'=>'Search filter for posixmember searches',
+			'default'=>'(uid=*)');
+
+		/**
+		 * posixGroup attribute. When this attribute are seen in modify_member_form.php, only posixGroup members are shown
+		 * See modify_member_form.php
+		 */
+		$this->default->modify_member['posixgroupattr'] = array(
+			'desc'=>'posixGroup member attribute',
+			'default'=>'memberUid');
+
 		## Session Attributes
 		/** Cookie Encryption
 		 * phpLDAPadmin can encrypt the content of sensitive cookies if you set this to a big random string.
@@ -217,6 +392,14 @@ class Config {
 			'desc'=>'Blowfish key to encrypt cookie details',
 			'default'=>null);
 
+		$this->default->session['memorylimit'] = array(
+			'desc'=>'Set the PHP memorylimit warning threshold.',
+			'default'=>24);
+
+		$this->default->session['timelimit'] = array(
+			'desc'=>'Set the PHP timelimit.',
+			'default'=>30);
+
 		/** Cookie Time
 		 * If you used auth_type 'form' in the servers list, you can adjust how long the cookie will last
 		 * (default is 0 seconds, which expires when you close the browser)
@@ -250,6 +433,10 @@ class Config {
 			'desc'=>'Whether to use similiar characters',
 			'default'=>true);
 
+		$this->default->password['no_random_crypt_salt'] = array(
+			'descr'=>'Disable random salt for crypt()',
+			'default'=>false);
+
 		/** Search display
 		 * By default, when searching you may display a list or a table of results.
 		 * Set this to 'table' to see table formatted results.
@@ -289,7 +476,7 @@ class Config {
 			'default'=>array('cn','sn','uid','postalAddress','telephoneNumber'));
 	}
 
-	function GetValue($key,$index) {
+	public function GetValue($key,$index) {
 
 		$value = null;
 
@@ -321,7 +508,7 @@ class Config {
 	/**
 	 * Function to check and warn about any unusual defined variables.
 	 */
-	function CheckCustom() {
+	public function CheckCustom() {
 		if (isset($this->custom)) {
 			foreach ($this->custom as $masterkey => $masterdetails) {
 
@@ -349,14 +536,100 @@ class Config {
 			}
 		}
 	}
+
+	/**
+	 * The parameter number is variable.
+	 * For example : isCommandAvailable('search', 'simple_search')
+	 */
+	public function isCommandAvailable() {
+		$a = func_get_args();
+		if (count($a) == 1 && is_array($a[0]))
+			$a = $a[0];
+		$i = 0;
+
+		# Command availability list
+		$cmd = $this->GetValue('commands','all');
+		# Search for the command
+		while ($i < count($a)) {
+			if (! is_array($cmd))
+				return $cmd;
+			if (! isset($cmd[$a[$i]]))
+				return false;
+
+			$cmd = $cmd[$a[$i]];
+			$i++;
+		}
+
+		# If this is a leaf command, return its availability
+		if (! is_array($cmd))
+			return $cmd;
+
+		# Else the command is available, if one of its sub-command is available
+		$a[] = '';
+		foreach ($cmd as $c => $v) {
+			$a[$i] = $c;
+			if ($this->isCommandAvailable($a))
+				return true;
+		}
+		return false;
+	}
+
+	/**
+	 * Reads the friendly_attrs array as defined in config.php and lower-cases all
+	 * the keys. Will return an empty array if the friendly_attrs array is not defined
+	 * in config.php. This is simply used so we can more easily lookup user-friendly
+	 * attributes configured by the admin.
+	 */
+	function getFriendlyAttrs($friendly_attrs) {
+		if (defined('DEBUG_ENABLED') && DEBUG_ENABLED)
+			debug_log('Entered with ()',1,__FILE__,__LINE__,__METHOD__);
+
+		# If friendly_attrs is not an array, then set to an empty array.
+		if (! is_array($friendly_attrs))
+			$this->friendly_attrs =  array();
+
+		else
+			foreach ($friendly_attrs as $old_name => $new_name)
+				$this->friendly_attrs[strtolower($old_name)] = $new_name;
+		}
+
+	/**
+	 * This function will return the friendly name of an attribute, if it exists.
+	 * If the friendly name doesnt exist, the attribute name will be returned.
+ 	 *
+	 * @param attribute
+	 * @return string friendly name|attribute
+	 */
+	public function getFriendlyName($attr) {
+		if ($this->haveFriendlyName($attr))
+			return $this->friendly_attrs[strtolower($attr)];
+		else
+			return $attr;
+	}
+
+	/**
+	 * This function will return true if a friendly name exists for an attribute.
+	 * If the friendly name doesnt exist, it will return false.
+ 	 *
+	 * @param attribute
+	 * @return boolean true|false
+	 */
+	public function haveFriendlyName($attr) {
+		return isset($this->friendly_attrs[strtolower($attr)]);
+
+	}
+
+	/**
+	 * This function will return the <ancronym> html for a friendly name attribute.
+ 	 *
+	 * @param attribute
+	 * @return string html for the friendly name.
+	 */
+	public function getFriendlyHTML($attr) {
+		if ($this->haveFriendlyName($attr))
+			return sprintf('<acronym title="%s %s">%s</acronym>',_('Alias for'),$attr,htmlspecialchars($this->getFriendlyName($attr)));
+		else
+			return $attr;
+	}
 }
-
-# Define our configuration variable.
-$config = new Config;
-require (CONFDIR.'config.php');
-
-if (($config->GetValue('debug','syslog') || $config->GetValue('debug','file')) && $config->GetValue('debug','level'))
-	define('DEBUG_ENABLED',1);
-else
-	define('DEBUG_ENABLED',0);
 ?>
